import pandas as pd

def clean_dataframe(df):
    """Cleans a DataFrame by:
    - Replacing NaN values with 0 for INT/BIGINT columns while keeping them as integers.
    - Replacing NaN values with 0.0 for FLOAT/DOUBLE/NUMERIC/DECIMAL columns.
    - Stripping leading/trailing whitespace from column names and replacing spaces with underscores.
    - Stripping leading/trailing whitespace from string values.
    - Replacing NaN in string columns with an empty string ("").
    """
    df = df.copy()  # Work on a copy to avoid modifying original data

    # ✅ Clean column names (trim spaces and replace internal spaces with underscores)
    df.columns = [col.strip().replace(" ", "_") for col in df.columns]

    for col in df.columns:
        if pd.api.types.is_integer_dtype(df[col]):
            df[col] = df[col].astype("Int64").fillna(0)  # ✅ Keeps INT type without converting to float
        elif pd.api.types.is_float_dtype(df[col]):
            df[col] = df[col].fillna(0.0)  # ✅ Ensures FLOAT columns get 0.0
        else:
            df[col] = df[col].astype(str).str.strip().replace({"nan": "", "None": ""})  # ✅ Replaces NaN with ""

    return df
